@@ -3,6 +3,7 @@ import time
 import string
 import inspect
 import requests
+import os
 import datetime
 import pandas as pd
 import dask.dataframe as dd
@@ -101,28 +102,10 @@ class DataNode(DatasetManager):
                 })
         return _response
     
-    def writeListDataNode(self, df=None, directory_id=None, name=None, description="", 
-              replace=None, profiling=False, lineage=None,
-              **kwargs):
-        """_summary_
 
-        Args:
-            df (_type_, optional): _description_. Defaults to None.
-            directory_id (_type_, optional): _description_. Defaults to None.
-            name (_type_, optional): _description_. Defaults to None.
-            description (str, optional): _description_. Defaults to "".
-            replace (_type_, optional): _description_. Defaults to None.
-            profiling (bool, optional): _description_. Defaults to False.
-            lineage (_type_, optional): _description_. Defaults to None.
-
-        Returns:
-            _type_: _description_
-        """
-        timestamp = datetime.datetime.now().strftime("%Y/%m/%d %H:%M:%S")
-        _response = self.write(df=df, directory=directory_id, name=f"{name}-{timestamp}", replace=replace, description=description, profiling=profiling, lineage=lineage)
-        _file_id = _response.get('file_id', 0)
-        
-        name = f'{name}.listDataNode'
+    def _write_listfile(self, type, file_name, file_id, directory_id, lineage, description):
+        _file_id = file_id
+        name = f'{file_name}.{type}'
         _is_file_exists = self._check_fileExists_no_ask(directory_id, name)
         
         if description == "":
@@ -197,6 +180,67 @@ class DataNode(DatasetManager):
             'file_id': meta.get('id'),
             'path': meta['path']
         }
+
+    def writeListFile(self, directory_id=None, file_path=None, description="", lineage=None, replace=None):
+        original_file_name = os.path.basename(file_path)
+        original_file_name, file_extension = original_file_name.split('.')
+
+        timestamp = datetime.datetime.now().strftime("%Y/%m/%d %H:%M:%S")
+        file_name = f"{original_file_name}-{timestamp}.{file_extension}"
+        
+
+        _response = self.upload_file(
+                directory_id=directory_id, 
+                file_path=file_path, 
+                file_name=file_name,
+                description=description, 
+                replace=True,
+            )
+        _file_id = _response.get('id', 0)
+
+        res = self._write_listfile(
+            type='listFile', 
+            file_name=original_file_name,
+            file_id=_file_id, 
+            directory_id=directory_id, 
+            lineage=lineage,
+            description=description,
+        )
+
+        return res
+        
+    
+    def writeListDataNode(self, df=None, directory_id=None, name=None, description="", 
+              replace=None, profiling=False, lineage=None,
+              **kwargs):
+        """_summary_
+
+        Args:
+            df (_type_, optional): _description_. Defaults to None.
+            directory_id (_type_, optional): _description_. Defaults to None.
+            name (_type_, optional): _description_. Defaults to None.
+            description (str, optional): _description_. Defaults to "".
+            replace (_type_, optional): _description_. Defaults to None.
+            profiling (bool, optional): _description_. Defaults to False.
+            lineage (_type_, optional): _description_. Defaults to None.
+
+        Returns:
+            _type_: _description_
+        """
+        timestamp = datetime.datetime.now().strftime("%Y/%m/%d %H:%M:%S")
+        _response = self.write(df=df, directory=directory_id, name=f"{name}-{timestamp}", replace=replace, description=description, profiling=profiling, lineage=lineage)
+        _file_id = _response.get('file_id', 0)
+
+        res = self._write_listfile(
+            type='listDataNode', 
+            file_name=name,
+            file_id=_file_id, 
+            directory_id=directory_id, 
+            lineage=lineage,
+            description=description,
+        )
+
+        return res
     
     def get_file(self, file_id=None):
         """_summary_
