@@ -1,20 +1,20 @@
 from clickhouse_driver import Client
 from tqdm.auto import tqdm
 
-def drop_table(client, table_name):
+def drop_table(client, table_name, verbose=True):
     try:
         client.execute(f'DROP TABLE {table_name}')
-        print(f'DROP TABLE {table_name} sucessful')
+        if verbose: print(f'DROP TABLE {table_name} sucessful')
         return True
     except Exception as e:
-        print(str(e))
+        if verbose: print(str(e))
         return False
 
 def get_info(ddf):
     datas = [{'column_name': col, 'data_type': str(ddf[col].dtype)} for col in ddf.columns]
     return datas
 
-def create_table(client, ddf, tableName, key):
+def create_table(client, ddf, tableName, partition_by):
     info = get_info(ddf)
     _map = {
         'int64': 'Int64',
@@ -28,7 +28,7 @@ def create_table(client, ddf, tableName, key):
         CREATE TABLE {tableName} ( 
             {sql_column}
         ) ENGINE = MergeTree
-        PARTITION BY {key} ORDER BY ({key})
+        PARTITION BY {partition_by} ORDER BY ({partition_by})
     """
     try:
         client.execute(sql_txt)
@@ -37,19 +37,17 @@ def create_table(client, ddf, tableName, key):
     else:
         return True, f"Create table {tableName} sucessful"
 
-def insert_df(df, connection, tableName):
+def insert_df(df, connection, tableName, n_row_per_loop=1000):
     if df.shape[0] == 0:
         return None
     for column in df:
         if 'datetime' in str(df[column].dtypes):
             df[column] = df[column].dt.strftime("%Y-%m-%d %H:%M:%S")
-    nPation_per_block = 1000
     sql_txt = f"""INSERT INTO {tableName} VALUES"""
     _client = Client(**connection)
-    for lower, upper in tqdm([(i, i+nPation_per_block) for i in range(0, df.shape[0], nPation_per_block)]):
+    for lower, upper in tqdm([(i, i+n_row_per_loop) for i in range(0, df.shape[0], n_row_per_loop)]):
         _client.insert_dataframe(sql_txt, df[lower:upper])
 
-def insert_ddf(connection, ddf, tableName):
-    nPation_per_block = 10
-    for lower, upper in tqdm([(i, i+nPation_per_block) for i in range(0, ddf.npartitions, nPation_per_block)]):
-        ddf.partitions[lower:upper].map_partitions(insert_df, connection=connection, tableName=tableName, meta=ddf).compute()
\ No newline at end of file
+def insert_ddf(connection, ddf, tableName, n_partition_per_block=10, n_row_per_loop=1000):
+    for lower, upper in tqdm([(i, i+n_partition_per_block) for i in range(0, ddf.npartitions, n_partition_per_block)]):
+        ddf.partitions[lower:upper].map_partitions(insert_df, connection=connection, tableName=tableName, n_row_per_loop=n_row_per_loop ,meta=ddf).compute()
\ No newline at end of file
